@@ -1,5 +1,6 @@
 from urllib.parse import urlparse
 
+from django.utils import timezone
 from drf_yasg import openapi
 from drf_yasg.utils import swagger_auto_schema, no_body
 from rest_framework import status
@@ -13,6 +14,7 @@ from drf_auth_service.authentication.serializers import CustomTokenRefreshSerial
 from drf_auth_service.common.managers import BaseManager
 from drf_auth_service.common.mixins import GenericEBSViewSet
 from drf_auth_service.common.register_backends import RegisterManager
+from drf_auth_service.models import SSOUser
 from drf_auth_service.settings import settings
 
 jwt_response = openapi.Response('Respond with jwt access&refresh token', ReturnRegisterSerializer)
@@ -100,6 +102,9 @@ class LoginViewSet(TokenViewBase):
             secure=True
         )
         response.cookies[settings.COOKIE_KEY]['samesite'] = 'None'
+
+        SSOUser.objects.filter(username=request.data.get('username')).update(last_login=timezone.now())
+
         return response
 
 
