@@ -2,7 +2,6 @@ import builtins
 
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.module_loading import import_string
-from virtualenv.config.convert import NoneType
 
 from drf_auth_service.common.email_backends import BaseEmailBackend
 from drf_auth_service.common.enums import RegisterType
@@ -21,7 +20,7 @@ class BaseManager:
         elif configs is None:
             raise Warning('Can not be both configs and request None')
         try:
-            self.backend = import_string(configs[self.backend_type])(configs)
+            self.backend = import_string(configs[self.backend_type])(configs, request)
             if not isinstance(self.backend, self.base_backend):
                 raise ImproperlyConfigured(
                     f"{configs[self.backend_type]} is not instance of BaseEmailBackend"
