@@ -27,6 +27,7 @@ class AbstractSSOUser(AbstractBaseUser):
     register_type = models.CharField(max_length=100, choices=RegisterType.choices, default=RegisterType.EMAIL)
     USERNAME_FIELD = 'username'
     objects = BaseUserManager()
+    created_at = models.DateTimeField(default=timezone.now())
 
     class Meta:
         db_table = '"users"'
@@ -153,7 +154,7 @@ class ActivationCode(models.Model):
 
 class UserLogs(models.Model):
     username = models.CharField(max_length=200)
-    user = models.ForeignKey(django_settings.AUTH_USER_MODEL, on_delete=models.CASCADE)
+    user = models.ForeignKey(django_settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name='logs')
     type_log = models.CharField(max_length=50, choices=LogsType.choices)
     service = models.ForeignKey(Service, related_name='service_logs', on_delete=models.CASCADE)
     created_at = models.DateTimeField(auto_now_add=True)
