@@ -4,13 +4,14 @@ from rest_framework.response import Response
 
 from drf_auth_service.common.mixins import EBSModelViewSet
 from drf_auth_service.models import Service, Config
+from drf_auth_service.services.permissions import SERVICE_PERMISSIONS
 from drf_auth_service.settings import settings
 
 
 class ServiceViewSet(EBSModelViewSet):
     serializer_class = settings.SERIALIZERS.SERVICE_SERIALIZER
     queryset = Service.objects.all()
-    permission_classes = [IsAuthenticated]
+    permission_classes_by_action = settings.PERMISSIONS.SERVICE_PERMISSIONS
 
     @action(detail=True, methods=['GET', 'PATCH'], url_name='configs')
     def configs(self, request, *args, **kwargs):
